@@ -4,9 +4,11 @@ use strict;
 use warnings;
 
 use Carp;
-use Exporter qw{ import };
+use Exporter;
 
-our $VERSION = '0.097';
+our @ISA = qw{ Exporter };
+
+our $VERSION = '0.098';
 
 our @EXPORT_OK = qw{ __any };
 
